pub enum ReadOptions {
IfNoneMatch(String),
IfMatch(String),
NoHeader,
}Expand description
Options for document reading.
Variants
IfNoneMatch(String)
If the “If-None-Match” header is given, then it must contain exactly one Etag. The document is returned, if it has a different revision than the given Etag. Otherwise an HTTP 304 is returned.
IfMatch(String)
If the “If-Match” header is given, then it must contain exactly one Etag. The document is returned, if it has the same revision as the given Etag. Otherwise a HTTP 412 is returned.
NoHeader