pub struct Graph {
pub name: String,
pub edge_definitions: Vec<EdgeDefinition>,
pub orphan_collections: Vec<String>,
pub is_smart: Option<bool>,
pub is_disjoint: Option<bool>,
pub options: Option<GraphOptions>,
}Expand description
Represents a Named Graph in ArangoDB.
Fields
name: StringName of the graph
edge_definitions: Vec<EdgeDefinition>An array of definitions for the relations of the graph.
orphan_collections: Vec<String>An array of additional vertex collections. Documents within these collections do not have edges within this graph.
is_smart: Option<bool>Define if the created graph should be smart (Enterprise Edition only).
is_disjoint: Option<bool>Whether to create a Disjoint SmartGraph instead of a regular SmartGraph (Enterprise Edition only).
options: Option<GraphOptions>a JSON object to define options for creating collections within this graph.
Implementations
Sourceimpl Graph
impl Graph
Sourcepub fn builder() -> GraphBuilder<((), (), (), (), (), ())>
pub fn builder() -> GraphBuilder<((), (), (), (), (), ())>
Create a builder for building Graph.
On the builder, call .name(...)(optional), .edge_definitions(...)(optional), .orphan_collections(...)(optional), .is_smart(...)(optional), .is_disjoint(...)(optional), .options(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of Graph.